diff --git a/src/checkstyle/com/puppycrawl/tools/checkstyle/checks/usage/transmogrify/ClassDef.java b/src/checkstyle/com/puppycrawl/tools/checkstyle/checks/usage/transmogrify/ClassDef.java
index b9291f895..2b8228445 100644
--- a/src/checkstyle/com/puppycrawl/tools/checkstyle/checks/usage/transmogrify/ClassDef.java
+++ b/src/checkstyle/com/puppycrawl/tools/checkstyle/checks/usage/transmogrify/ClassDef.java
@@ -79,16 +79,16 @@ public class ClassDef extends DefaultScope implements IClass {
return ++id;
}
- public void setSuperclass(IClass superclass) {
- this.superclass = superclass;
+ public void setSuperclass(IClass newSuperclass) {
+ this.superclass = newSuperclass;
}
public IClass getSuperclass() {
return superclass;
}
- public void addUnprocessedImports(Vector imports) {
- unprocessedImports = (Vector) (imports.clone());
+ public void addUnprocessedImports(Vector aImports) {
+ unprocessedImports = (Vector) (aImports.clone());
}
public Vector getUnprocessedImports() {
@@ -177,11 +177,11 @@ public class ClassDef extends DefaultScope implements IClass {
}
if (result == null) {
- IClass[] interfaces = getInterfaces();
+ IClass[] myInterfaces = getInterfaces();
for (int index = 0;
- index < interfaces.length && result == null;
+ index < myInterfaces.length && result == null;
index++) {
- result = interfaces[index].getMethodDefinition(name, signature);
+ result = myInterfaces[index].getMethodDefinition(name, signature);
}
}
diff --git a/src/checkstyle/com/puppycrawl/tools/checkstyle/checks/usage/transmogrify/QueryEngine.java b/src/checkstyle/com/puppycrawl/tools/checkstyle/checks/usage/transmogrify/QueryEngine.java
index ee2e23f2d..49ccb2be1 100644
--- a/src/checkstyle/com/puppycrawl/tools/checkstyle/checks/usage/transmogrify/QueryEngine.java
+++ b/src/checkstyle/com/puppycrawl/tools/checkstyle/checks/usage/transmogrify/QueryEngine.java
@@ -43,8 +43,8 @@ public class QueryEngine {
private SymbolTable symbolTable;
private ScopeIndex index;
- public QueryEngine(SymbolTable symbolTable) {
- this.symbolTable = symbolTable;
+ public QueryEngine(SymbolTable aSymbolTable) {
+ this.symbolTable = aSymbolTable;
setIndex();
}
diff --git a/src/checkstyle/com/puppycrawl/tools/checkstyle/checks/usage/transmogrify/SymbolTable.java b/src/checkstyle/com/puppycrawl/tools/checkstyle/checks/usage/transmogrify/SymbolTable.java
index 3e1036702..72cdcf94f 100644
--- a/src/checkstyle/com/puppycrawl/tools/checkstyle/checks/usage/transmogrify/SymbolTable.java
+++ b/src/checkstyle/com/puppycrawl/tools/checkstyle/checks/usage/transmogrify/SymbolTable.java
@@ -65,11 +65,11 @@ public class SymbolTable {
/**
* constructor takes SymTabAST
* @param root root of the SymTabAST tree
*/
- public SymbolTable(SymTabAST root) {
+ public SymbolTable(SymTabAST aRoot) {
scopes = new Stack();
- this.root = root;
+ this.root = aRoot;
baseScope = new BaseScope( this );
pushScope(baseScope);
@@ -65,11 +65,11 @@ public class SymbolTable {
/**
* constructor takes SymTabAST
- * @param root root of the SymTabAST tree
+ * @param aRoot root of the SymTabAST tree
*/